/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
import * as vm from 'vm';
export interface ContextConfiguration {
    appId: string;
    appName: string;
    environmentUrl: string;
    token: string;
    tenantId?: string;
    devProxyUrl: string;
}
export interface RuntimeContext {
    /** The Node.js `vm` context */
    vmContext: vm.Context;
    /**
     * This function should be called from outside when an unhandled promise rejection was detected
     * @returns `false` if `preventDefault` was called, otherwise `true`
     */
    reportUnhandledRejection: (reason: any, promise: Promise<unknown>) => boolean;
}
/** Creates a new VM context */
export declare function createContext(cwd: string, urlPathname: string, config?: ContextConfiguration): RuntimeContext;
